Modules
- array
[u8; N]array functions. Small helper functions for[u8; N]arrays.- backoff
- Exponential backoff.
- const_
utils - Utilities for use in
constfns and expressions. Utilities for use inconstfns and expressions. - fmt
fmtextensions.- iter
- Iterator extensions.
- path
- Path extensions.
- string
- String utilities. String utilities.
Macros
- const_
assert - Assert at compile that that a boolean expression evaluates to true. Implementation copied from the static_assertions crate.
- const_
assert_ mem_ size - Assert at compile time that a type has a specific in-memory size in bytes.
- const_
assert_ usize_ eq - Assert at compile time that two
usizevalues are equal. This assert has a nice benefit where there compiler error will actually print out the two values. - const_
concat_ bytes - Easily concatenate multiple const
&[u8]slices into a single const&[u8]. - const_
concat_ str - Easily concatenate multiple const
&strslices into a single const&str.