Module backoff

Module backoff 

Exponential backoff.

Structs

Backoff
Exponential backoff iterator yielding Durations.

Functions

get_backoff_iter
Get a iterator of Durations which can be passed into e.g. tokio::time::sleep to observe time-based exponential backoff.
iter_with_initial_wait_ms
Like get_backoff_iter, but allows specifying the initial wait time in milliseconds.