pub fn iter_with_initial_wait_ms(initial_wait_ms: u64) -> Backoff ⓘExpand description
Like get_backoff_iter, but allows specifying the initial wait time in
milliseconds.
pub fn iter_with_initial_wait_ms(initial_wait_ms: u64) -> Backoff ⓘLike get_backoff_iter, but allows specifying the initial wait time in
milliseconds.