DebugIter

Struct DebugIter 

pub struct DebugIter<I>(pub I);
Displays an iterator of items using each element’s fmt::Debug impl.

As fmt::Display can’t take ownership of the underlying iterator, the iterator is cloned every time it is displayed, so it should be cheaply clonable (most iterators are).

Tuple Fields

0: I