macro_rules! const_assert {
($x:expr $(,)?) => { ... };
}Expand description
Assert at compile that that a boolean expression evaluates to true. Implementation copied from the static_assertions crate.
macro_rules! const_assert {
($x:expr $(,)?) => { ... };
}Assert at compile that that a boolean expression evaluates to true. Implementation copied from the static_assertions crate.