macro_rules! const_assert_usize_eq {
($x:expr, $y:expr $(,)?) => { ... };
}Expand description
Assert at compile time that two usize values are equal. This assert has a
nice benefit where there compiler error will actually print out the
two values.